..
  Licensed under the Apache License, Version 2.0 (the "License"); you may
  not use this file except in compliance with the License. You may obtain
  a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
  License for the specific language governing permissions and limitations
  under the License.

====================================
Welcome to the Senlin documentation!
====================================

Senlin is a service to create and manage :term:`cluster` of multiple cloud
resources. Senlin provides an OpenStack-native REST API and a AWS
AutoScaling-compatible Query API is in plan.

This documentation offers information on how Senlin works and how to
contribute to the project.

.. toctree::
   :maxdepth: 1

   overview
   install
   configuration
   tutorial/index
   user/index
   developer/index
   glossary

API Documentation
~~~~~~~~~~~~~~~~~

Follow the link below for the Senlin API V1 specification:

-  `OpenStack API Complete Reference - Clustering`_


Man Pages
~~~~~~~~~

.. toctree::
   :maxdepth: 1

   man/index

Indices and tables
~~~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`search`


.. _`OpenStack API Complete Reference - Clustering`: http://developer.openstack.org/api-ref/clustering/
